@@ -1,4 +1,4 @@
-/* $XConsortium: SimpleMenu.c,v 1.41 92/09/10 16:25:07 converse Exp $ */
+/* $XConsortium: SimpleMenu.c,v 1.44 94/04/17 20:12:45 kaleb Exp $ */
 
 /*
 Copyright (c) 1989, 1994  X Consortium
@@ -476,7 +476,7 @@ Widget w;
 ArgList arglist;
 Cardinal *num_args;
 {
-    register Cardinal i;
+    Cardinal i;
     Dimension width, height;
     
     width = w->core.width;
@@ -749,8 +749,8 @@ Cardinal * num_params;
     SmeObject entry = smw->simple_menu.entry_set;
     SmeObjectClass class;
     
-    if ( (entry == NULL) || !XtIsSensitive((Widget) entry) ) return;
-
+    if ( (entry == NULL) || !XtIsSensitive((Widget) entry ) ) return;
+    
     class = (SmeObjectClass) entry->object.widget_class;
     (class->sme_class.notify)( (Widget) entry );
 }
@@ -838,8 +838,8 @@ CreateLabel(w)
 Widget w;
 {
     SimpleMenuWidget smw = (SimpleMenuWidget) w;
-    register Widget * child, * next_child;
-    register int i;
+    Widget * child, * next_child;
+    int i;
     Arg args[2];
 
     if ( (smw->simple_menu.label_string == NULL) ||
@@ -990,7 +990,7 @@ FindMenu(widget, name)
 Widget widget;
 String name;
 {
-    register Widget w, menu;
+    Widget w, menu;
     
     for ( w = widget ; w != NULL ; w = XtParent(w) )
 	if ( (menu = XtNameToWidget(w, name)) != NULL )
@@ -1023,7 +1023,7 @@ XPoint * location;
 	if (XQueryPointer(XtDisplay(w), XtWindow(w), &junk1, &junk2, 
 			  &root_x, &root_y, &junkX, &junkY, &junkM) == FALSE) {
 	    char error_buf[BUFSIZ];
-	    (void) sprintf(error_buf, "%s %s", "Xaw - SimpleMenuWidget:",
+	    (void) sprintf(error_buf, "%s %s", "Xaw Simple Menu Widget:",
 		    "Could not find location of mouse pointer");
 	    XtAppWarning(XtWidgetToApplicationContext(w), error_buf);
 	    return;
@@ -1233,7 +1233,7 @@ GetEventEntry(w, event)
 Widget w;
 XEvent * event;
 {
-    Position x_loc, y_loc;
+    Position x_loc = 0, y_loc = 0;
     SimpleMenuWidget smw = (SimpleMenuWidget) w;
     SmeObject * entry;
     
@@ -1275,4 +1275,3 @@ XEvent * event;
     
     return(NULL);
 }
-
