@@ -1,4 +1,4 @@
-/* $XConsortium: SmeBSB.c,v 1.17 91/10/16 21:39:58 eswu Exp $ */
+/* $XConsortium: SmeBSB.c,v 1.19 94/04/17 20:12:49 kaleb Exp $ */
 
 /*
 Copyright (c) 1989, 1994  X Consortium
@@ -25,10 +25,21 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from the X Consortium.
  */
 
+/*
+ * SmeBSB.c - Source code file for BSB Menu Entry object.
+ *
+ * Date:    September 26, 1989
+ *
+ * By:      Chris D. Peterson
+ *          MIT X Consortium 
+ *          kit@expo.lcs.mit.edu
+ */
+
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
 #include <X11/Xos.h>
 
+/* needed for abs() */
 #ifdef X_NOT_STDC_ENV
 extern int abs();
 #else
@@ -67,8 +78,8 @@ static XtResource resources[] = {
      offset(foreground), XtRString, XtDefaultForeground},
   {XtNfont,  XtCFont, XtRFontStruct, sizeof(XFontStruct *),
      offset(font), XtRString, XtDefaultFont},
-  {XtNfontSet, XtCFontSet, XtRFontSet, sizeof(XFontSet),
-     offset(fontset), XtRString, XtDefaultFontSet}
+  {XtNfontSet,  XtCFontSet, XtRFontSet, sizeof(XFontSet ),
+     offset(fontset),XtRString, XtDefaultFontSet},
 };   
 #undef offset
 
@@ -227,20 +238,23 @@ Region region;
     GC gc;
     SmeBSBObject entry = (SmeBSBObject) w;
     Dimension s = entry->sme_threeD.shadow_width;
-    int	font_ascent, font_descent, y_loc;
-    int fontset_ascent, fontset_descent;
-    XFontSetExtents* ext = XExtentsOfFontSet(entry->sme_bsb.fontset);
+    int	font_ascent = 0, font_descent = 0, y_loc;
+
+    int	fontset_ascent = 0, fontset_descent = 0;
+    XFontSetExtents *ext = XExtentsOfFontSet(entry->sme_bsb.fontset);
 
     entry->sme_bsb.set_values_area_cleared = FALSE;    
     if ( entry->sme.international == True ) {
-	fontset_ascent = abs(ext->max_ink_extent.y);
-	fontset_descent = ext->max_ink_extent.height - fontset_ascent;
-    } else {
-	font_ascent = entry->sme_bsb.font->max_bounds.ascent;
-	font_descent = entry->sme_bsb.font->max_bounds.descent;
+        fontset_ascent = abs(ext->max_ink_extent.y);
+        fontset_descent = ext->max_ink_extent.height - fontset_ascent;
+    }
+    else { /*else, compute size from font like R5*/
+        font_ascent = entry->sme_bsb.font->max_bounds.ascent;
+        font_descent = entry->sme_bsb.font->max_bounds.descent;
     }
     y_loc = entry->rectangle.y;
 
+
     if (XtIsSensitive(w) && XtIsSensitive( XtParent(w) ) ) {
 	if ( w == XawSimpleMenuGetActiveEntry(XtParent(w)) ) {
 	    XFillRectangle(XtDisplayOfObject(w), XtWindowOfObject(w), 
@@ -264,47 +278,52 @@ Region region;
 	    int width, t_width;
 
 	case XtJustifyCenter:
-	    if ( entry->sme.international == True ) {
-	      t_width = XmbTextEscapement(entry->sme_bsb.fontset,label,len);
-	      width = entry->rectangle.width -
-		(entry->sme_bsb.left_margin + entry->sme_bsb.right_margin);
-	    } else {
-	      t_width = XTextWidth(entry->sme_bsb.font, label, len);
-	      width = entry->rectangle.width - (entry->sme_bsb.left_margin +
+            if ( entry->sme.international == True ) {
+	        t_width = XmbTextEscapement(entry->sme_bsb.fontset,label,len);
+                width = entry->rectangle.width - (entry->sme_bsb.left_margin +
 					      entry->sme_bsb.right_margin);
-	    }
+            }
+            else {
+	        t_width = XTextWidth(entry->sme_bsb.font, label, len);
+	        width = entry->rectangle.width - (entry->sme_bsb.left_margin +
+					      entry->sme_bsb.right_margin);
+            }
 	    x_loc += (width - t_width)/2;
 	    break;
 	case XtJustifyRight:
-	    if (entry->sme.international == True ) {
-	      t_width = XmbTextEscapement(entry->sme_bsb.fontset,label,len);
-	      x_loc = entry->rectangle.width - (entry->sme_bsb.right_margin +
-					      t_width);
-	    } else {
-	      t_width = XTextWidth(entry->sme_bsb.font, label, len);
-	      x_loc = entry->rectangle.width - (entry->sme_bsb.right_margin +
-					      t_width);
-	    }
+            if ( entry->sme.international == True ) {
+                t_width = XmbTextEscapement(entry->sme_bsb.fontset,label,len);
+                x_loc = entry->rectangle.width - ( entry->sme_bsb.right_margin
+						 + t_width );
+            }
+            else {
+	        t_width = XTextWidth(entry->sme_bsb.font, label, len);
+	        x_loc = entry->rectangle.width - ( entry->sme_bsb.right_margin
+						 + t_width );
+            }
 	    break;
 	case XtJustifyLeft:
 	default:
 	    break;
 	}
 
-	/* this will center the text in the gadget top-to-bottom */
-	if ( entry->sme.international == True ) {
-	    y_loc += ((int)entry->rectangle.height - 
-		(fontset_ascent + fontset_descent)) / 2 + fontset_ascent;
 
-	    XmbDrawString(XtDisplayOfObject(w), XtWindowOfObject(w), 
-		entry->sme_bsb.fontset, gc, x_loc + s, y_loc, label, len);
-	} else {
-	    y_loc += ((int)entry->rectangle.height - 
-		(font_ascent + font_descent)) / 2 + font_ascent;
+	/* this will center the text in the gadget top-to-bottom */
+
+        if ( entry->sme.international==True ) {
+            y_loc += ((int)entry->rectangle.height - 
+		  (fontset_ascent + fontset_descent)) / 2 + fontset_ascent;
+
+            XmbDrawString(XtDisplayOfObject(w), XtWindowOfObject(w),
+                entry->sme_bsb.fontset, gc, x_loc + s, y_loc, label, len);
+        }
+        else {
+            y_loc += ((int)entry->rectangle.height - 
+		  (font_ascent + font_descent)) / 2 + font_ascent;
 	
-	    XDrawString(XtDisplayOfObject(w), XtWindowOfObject(w), gc,
-		x_loc + s, y_loc, label, len);
-	}
+            XDrawString(XtDisplayOfObject(w), XtWindowOfObject(w), gc,
+		    x_loc + s, y_loc, label, len);
+        }
     }
 
     DrawBitmaps(w, gc);
@@ -353,17 +372,18 @@ Cardinal *num_args;
 	ret_val = TRUE;
     }
 
-    if ( ( (old_entry->sme_bsb.font != entry->sme_bsb.font) &&
-	    (old_entry->sme.international == False) ) ||
-	 (old_entry->sme_bsb.foreground != entry->sme_bsb.foreground) ) {
+    if (  (	(old_entry->sme_bsb.font != entry->sme_bsb.font) &&
+	(old_entry->sme.international == False )	          ) ||
+	(old_entry->sme_bsb.foreground != entry->sme_bsb.foreground) ) {
 	DestroyGCs(current);
 	CreateGCs(new);
 	ret_val = TRUE;
     }
 
     if ( ( old_entry->sme_bsb.fontset != entry->sme_bsb.fontset) &&
-	    ( old_entry->sme.international == True) )
-	ret_val = TRUE;
+				(old_entry->sme.international == True ) )
+        /* DONT changes the GCs, because the fontset is not in them. */
+        ret_val = TRUE;
 
     if (ret_val) {
 	GetDefaultSize(new, 
@@ -471,39 +491,37 @@ Dimension * width, * height;
 {
     SmeBSBObject entry = (SmeBSBObject) w;
 
-  if ( entry->sme.international == True ) {
-    XFontSetExtents* ext = XExtentsOfFontSet(entry->sme_bsb.fontset);
-    if (entry->sme_bsb.label == NULL)
-      *width = 0;
-    else
-      *width = XmbTextEscapement(entry->sme_bsb.fontset, entry->sme_bsb.label,
-				 strlen(entry->sme_bsb.label));
-
-    *width += entry->sme_bsb.left_margin + entry->sme_bsb.right_margin;
-    *width += (2 * entry->sme_threeD.shadow_width);
-
-    *height = ext->max_ink_extent.height;
-    *height = ((int) *height * (ONE_HUNDRED +
-		entry->sme_bsb.vert_space )) / ONE_HUNDRED;
-    *height += (2 * entry->sme_threeD.shadow_width);
-  } else {
-
-    if (entry->sme_bsb.label == NULL) 
-	*width = 0;
-    else
-	*width = XTextWidth(entry->sme_bsb.font, entry->sme_bsb.label,
+    if ( entry->sme.international == True ) {
+        XFontSetExtents *ext = XExtentsOfFontSet(entry->sme_bsb.fontset);
+        if (entry->sme_bsb.label == NULL) 
+	    *width = 0;
+        else
+	    *width = XmbTextEscapement(entry->sme_bsb.fontset, entry->sme_bsb.label,
+			    strlen(entry->sme_bsb.label));
+        *width += entry->sme_bsb.left_margin + entry->sme_bsb.right_margin;
+        *width += (2 * entry->sme_threeD.shadow_width);
+        *height = ext->max_ink_extent.height;
+        *height = ((int)*height * ( ONE_HUNDRED + 
+			        entry->sme_bsb.vert_space )) / ONE_HUNDRED;
+        *height += (2 * entry->sme_threeD.shadow_width);
+    }
+    else {
+        if (entry->sme_bsb.label == NULL) 
+	    *width = 0;
+        else
+	    *width = XTextWidth(entry->sme_bsb.font, entry->sme_bsb.label,
 			    strlen(entry->sme_bsb.label));
 
-    *width += entry->sme_bsb.left_margin + entry->sme_bsb.right_margin;
-    *width += (2 * entry->sme_threeD.shadow_width);
+        *width += entry->sme_bsb.left_margin + entry->sme_bsb.right_margin;
+        *width += (2 * entry->sme_threeD.shadow_width);
     
-    *height = (entry->sme_bsb.font->max_bounds.ascent +
+        *height = (entry->sme_bsb.font->max_bounds.ascent +
 	       entry->sme_bsb.font->max_bounds.descent);
 
-    *height = ((int)*height * ( ONE_HUNDRED + 
+        *height = ((int)*height * ( ONE_HUNDRED + 
 			        entry->sme_bsb.vert_space )) / ONE_HUNDRED;
-    *height += (2 * entry->sme_threeD.shadow_width);
-  }
+        *height += (2 * entry->sme_threeD.shadow_width);
+    }
 }
 
 /*      Function Name: DrawBitmaps
@@ -589,13 +607,13 @@ Boolean is_left;
 	    if (!XGetGeometry(XtDisplayOfObject(w), 
 			      entry->sme_bsb.left_bitmap, &root, 
 			      &x, &y, &width, &height, &bw, &depth)) {
-		(void) sprintf(buf, "SmeBSB Object: %s %s \"%s\".", "Could not",
+		(void) sprintf(buf, "Xaw SmeBSB Object: %s %s \"%s\".", "Could not",
 			"get Left Bitmap geometry information for menu entry ",
 			XtName(w));
 		XtAppError(XtWidgetToApplicationContext(w), buf);
 	    }
 	    if (depth != 1) {
-		(void) sprintf(buf, "SmeBSB Object: %s \"%s\"%s.", 
+		(void) sprintf(buf, "Xaw SmeBSB Object: %s \"%s\"%s.", 
 			"Left Bitmap of entry ", 
 			XtName(w), " is not one bit deep.");
 		XtAppError(XtWidgetToApplicationContext(w), buf);
@@ -608,13 +626,13 @@ Boolean is_left;
 	if (!XGetGeometry(XtDisplayOfObject(w),
 			  entry->sme_bsb.right_bitmap, &root,
 			  &x, &y, &width, &height, &bw, &depth)) {
-	    (void) sprintf(buf, "SmeBSB Object: %s %s \"%s\".", "Could not",
+	    (void) sprintf(buf, "Xaw SmeBSB Object: %s %s \"%s\".", "Could not",
 		    "get Right Bitmap geometry information for menu entry ",
 		    XtName(w));
 	    XtAppError(XtWidgetToApplicationContext(w), buf);
 	}
 	if (depth != 1) {
-	    (void) sprintf(buf, "SmeBSB Object: %s \"%s\"%s.", 
+	    (void) sprintf(buf, "Xaw SmeBSB Object: %s \"%s\"%s.", 
 		    "Right Bitmap of entry ", XtName(w),
 		    " is not one bit deep.");
 	    XtAppError(XtWidgetToApplicationContext(w), buf);
@@ -642,21 +660,20 @@ Widget w;
     values.background = entry->sme_bsb.foreground;
     values.font = entry->sme_bsb.font->fid;
     values.graphics_exposures = FALSE;
-    mask        = GCForeground | GCBackground | GCGraphicsExposures | GCFont;
-    mask_i18n   = GCForeground | GCBackground | GCGraphicsExposures;
-
+    mask      = GCForeground | GCBackground | GCGraphicsExposures | GCFont;
+    mask_i18n = GCForeground | GCBackground | GCGraphicsExposures;
     if ( entry->sme.international == True )
-      entry->sme_bsb.rev_gc = XtAllocateGC(w, 0, mask_i18n, &values, GCFont, 0);
+        entry->sme_bsb.rev_gc = XtAllocateGC(w, 0, mask_i18n, &values, GCFont, 0 );
     else
-      entry->sme_bsb.rev_gc = XtGetGC(w, mask, &values);
+        entry->sme_bsb.rev_gc = XtGetGC(w, mask, &values);
     
     values.foreground = entry->sme_bsb.foreground;
     values.background = XtParent(w)->core.background_pixel;
     if ( entry->sme.international == True )
-      entry->sme_bsb.norm_gc = XtAllocateGC(w, 0, mask_i18n, &values, GCFont, 0);
+        entry->sme_bsb.norm_gc = XtAllocateGC(w, 0, mask_i18n, &values, GCFont, 0 );
     else
-      entry->sme_bsb.norm_gc = XtGetGC(w, mask, &values);
-    
+        entry->sme_bsb.norm_gc = XtGetGC(w, mask, &values);
+
     values.fill_style = FillTiled;
     values.tile   = XmuCreateStippledPixmap(XtScreenOfObject(w), 
 					    entry->sme_bsb.foreground,
@@ -664,12 +681,11 @@ Widget w;
 					    XtParent(w)->core.depth);
     values.graphics_exposures = FALSE;
     mask |= GCTile | GCFillStyle;
-    mask_i18n |= GCTile | GCFillStyle;
     if ( entry->sme.international == True )
-      entry->sme_bsb.norm_gray_gc = XtAllocateGC(w, 0, mask_i18n, &values, GCFont, 0);
+        entry->sme_bsb.norm_gray_gc = XtAllocateGC(w, 0, mask_i18n, &values, GCFont, 0 );
     else
-      entry->sme_bsb.norm_gray_gc = XtGetGC(w, mask, &values);
-    
+        entry->sme_bsb.norm_gray_gc = XtGetGC(w, mask, &values);
+
     values.foreground ^= values.background;
     values.background = 0;
     values.function = GXxor;
@@ -710,4 +726,3 @@ void _XawSmeBSBApolloHack ()
     FlipColors();
 }
 #endif /* apollo */
-
