@@ -1,4 +1,4 @@
-/* $XConsortium: StripChart.c,v 1.21 91/10/16 21:40:06 eswu Exp $ */
+/* $XConsortium: StripChart.c,v 1.25 94/04/17 20:12:56 kaleb Exp $ */
 
 /***********************************************************
 
@@ -30,13 +30,13 @@ Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
 
-Permission to use, copy, modify, and distribute this software and its
-documentation for any purpose and without fee is hereby granted,
+Permission to use, copy, modify, and distribute this software and its 
+documentation for any purpose and without fee is hereby granted, 
 provided that the above copyright notice appear in all copies and that
-both that copyright notice and this permission notice appear in
+both that copyright notice and this permission notice appear in 
 supporting documentation, and that the name of Digital not be
 used in advertising or publicity pertaining to distribution of the
-software without specific, written prior permission.
+software without specific, written prior permission.  
 
 DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
 ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
@@ -82,7 +82,7 @@ static XtResource resources[] = {
 
 #undef offset
 
-static void Initialize(), Destroy(), Redisplay(), MoveChart(), Resize();
+static void Initialize(), Destroy(), Redisplay(), MoveChart(), SetPoints();
 static Boolean SetValues();
 static int repaint_window();
 
@@ -108,7 +108,7 @@ StripChartClassRec stripChartClassRec = {
     /* compress_enterleave	*/	TRUE,
     /* visible_interest		*/	FALSE,
     /* destroy			*/	Destroy,
-    /* resize			*/	Resize,
+    /* resize			*/	SetPoints,
     /* expose			*/	Redisplay,
     /* set_values		*/	SetValues,
     /* set_values_hook		*/	NULL,
@@ -122,7 +122,7 @@ StripChartClassRec stripChartClassRec = {
     /* display_accelerator	*/	XtInheritDisplayAccelerator,
     /* extension		*/	NULL
     },
-    { /* Simple fields */
+    { /* Simple class fields */
     /* change_sensitive		*/	XtInheritChangeSensitive
     },
     { /* ThreeD fields */
@@ -206,19 +206,19 @@ static void Initialize (greq, gnew, args, num_args)
     w->strip_chart.interval = 0;
     w->strip_chart.max_value = 0.0;
     w->strip_chart.points = NULL;
-    Resize((Widget)w);
+    SetPoints((Widget)w);
 }
  
 static void Destroy (gw)
      Widget gw;
 {
-    StripChartWidget w = (StripChartWidget)gw;
+     StripChartWidget w = (StripChartWidget)gw;
 
-    if (w->strip_chart.update > 0)
-	XtRemoveTimeOut (w->strip_chart.interval_id);
-    if (w->strip_chart.points)
-	XtFree((char *) w->strip_chart.points);
-    DestroyGC(w, (unsigned int) ALL_GCS);
+     if (w->strip_chart.update > 0)
+         XtRemoveTimeOut (w->strip_chart.interval_id);
+     if (w->strip_chart.points)
+	 XtFree((char *) w->strip_chart.points);
+     DestroyGC(w, (unsigned int) ALL_GCS);
 }
 
 /*
@@ -254,69 +254,68 @@ draw_it(client_data, id)
 XtPointer client_data;
 XtIntervalId *id;		/* unused */
 {
-    StripChartWidget w = (StripChartWidget)client_data;
-    StripChartWidgetClass swclass = (StripChartWidgetClass) XtClass ((Widget) w);
-    Dimension s = w->threeD.shadow_width;
-    double value;
+   StripChartWidget w = (StripChartWidget)client_data;
+   StripChartWidgetClass swclass = (StripChartWidgetClass) XtClass ((Widget) w);
+   Dimension s = w->threeD.shadow_width;
+   double value;
    
-    if (w->strip_chart.update > 0)
-	w->strip_chart.interval_id =
-	    XtAppAddTimeOut(XtWidgetToApplicationContext( (Widget) w),
-		            (unsigned long) w->strip_chart.update * MS_PER_SEC,
-			    draw_it, client_data);
+   if (w->strip_chart.update > 0)
+       w->strip_chart.interval_id =
+       XtAppAddTimeOut(XtWidgetToApplicationContext( (Widget) w),
+		       (unsigned long) w->strip_chart.update * MS_PER_SEC,
+		       draw_it, client_data);
 
-    if (w->strip_chart.interval >= (int)( w->core.width - 2 * s))
-	MoveChart( (StripChartWidget) w, TRUE);
+   if (w->strip_chart.interval >= (int)( w->core.width - 2 * s))
+       MoveChart( (StripChartWidget) w, TRUE);
 
-    /* Get the value, stash the point and draw corresponding line. */
+   /* Get the value, stash the point and draw corresponding line. */
 
-    if (w->strip_chart.get_value == NULL)
-	return;
+   if (w->strip_chart.get_value == NULL)
+       return;
 
-    XtCallCallbacks( (Widget)w, XtNgetValue, (XtPointer)&value );
+   XtCallCallbacks( (Widget)w, XtNgetValue, (XtPointer)&value );
 
    /* 
     * Keep w->strip_chart.max_value up to date, and if this data 
     * point is off the graph, change the scale to make it fit. 
     */
    
-    if (value > w->strip_chart.max_value) {
-	w->strip_chart.max_value = value;
-	if (w->strip_chart.max_value > w->strip_chart.scale) {
-	    XClearWindow(XtDisplay ((Widget) w), XtWindow ((Widget) w));
-	    w->strip_chart.interval = 
-	    repaint_window((Widget)w, 0, w->core.width - 2 * s);
-	    (*swclass->threeD_class.shadowdraw) ((Widget) w, 
-						 (XEvent *)0, (Region)0, 
-						 FALSE);
-	}
-    }
+   if (value > w->strip_chart.max_value) {
+       w->strip_chart.max_value = value;
+       if (XtIsRealized((Widget)w) && 
+	   w->strip_chart.max_value > w->strip_chart.scale) {
+	   XClearWindow(XtDisplay ((Widget) w), XtWindow ((Widget) w));
+	   w->strip_chart.interval = repaint_window((Widget)w, 0, (int) w->core.width - 2 * s);
+	   (*swclass->threeD_class.shadowdraw) ((Widget) w, 
+						(XEvent *)0, (Region)0, 
+						FALSE);
+       }
+   }
 
-    w->strip_chart.valuedata[w->strip_chart.interval] = value;
-    if (XtIsRealized((Widget) w)) {
+   w->strip_chart.valuedata[w->strip_chart.interval] = value;
+   if (XtIsRealized((Widget)w)) {
        int y = (int) (( w->core.height - 2 * s)
-		      - (int)(( w->core.height - 2 * s) * value)
-                      / w->strip_chart.scale);
+		      - (int)(( w->core.height - 2 * s) * value) / w->strip_chart.scale);
 
-	XFillRectangle( XtDisplay((Widget) w), XtWindow((Widget) w), 
-			w->strip_chart.fgGC, w->strip_chart.interval + s, 
-			y + s, (unsigned int) 1, 
-			(w->core.height - 2 * s) - y);
+	XFillRectangle(XtDisplay((Widget) w), XtWindow((Widget) w), w->strip_chart.fgGC,
+		       w->strip_chart.interval + s, 
+		       y + s, (unsigned int) 1, 
+		       (w->core.height - 2 * s) - y);
        /*
 	* Fill in the graph lines we just painted over.
 	*/
 
-	if (w->strip_chart.points != NULL) {
-	    w->strip_chart.points[0].x = w->strip_chart.interval + s;
-	    XDrawPoints(XtDisplay(w), XtWindow(w), w->strip_chart.hiGC,
+       if (w->strip_chart.points != NULL) {
+	   w->strip_chart.points[0].x = w->strip_chart.interval + s;
+	   XDrawPoints(XtDisplay(w), XtWindow(w), w->strip_chart.hiGC,
 		       w->strip_chart.points, w->strip_chart.scale,
 		       CoordModePrevious);
-	}
+       }
 
-	XFlush(XtDisplay(w));		    /* Flush output buffers */
-    }
-    w->strip_chart.interval++;		    /* Next point */
-}
+       XFlush(XtDisplay(w));		    /* Flush output buffers */
+   }
+   w->strip_chart.interval++;		    /* Next point */
+} /* draw_it */
 
 /* Blts data according to current size, then redraws the stripChart window.
  * Next represents the number of valid points in data.  Returns the (possibly)
@@ -331,13 +330,13 @@ XtIntervalId *id;		/* unused */
 static int 
 repaint_window(gw, left, width)
 Widget gw;
-Dimension left, width;
+int left, width;
 {
     StripChartWidget w = (StripChartWidget) gw;
     Dimension s = w->threeD.shadow_width;
     StripChartWidgetClass swclass = (StripChartWidgetClass) XtClass ((Widget) w);
-    register int i, j;
-    register int next = w->strip_chart.interval;
+    int i, j;
+    int next = w->strip_chart.interval;
     int scale = w->strip_chart.scale;
     int scalewidth = 0;
 
@@ -354,7 +353,7 @@ Dimension left, width;
       width = next;				/* check this */
       scalewidth = w->core.width - 2 * s;
 
-      Resize(gw);
+      SetPoints(gw);
 
       if (XtIsRealized (gw)) {
 	XClearWindow (XtDisplay (gw), XtWindow (gw));
@@ -374,9 +373,9 @@ Dimension left, width;
 
 	/* Draw data point lines. */
 	for (i = left; i < width; i++) {
-	    int y = (int) (( w->core.height - 2 * s)
-			   - (int)(( w->core.height - 2 * s) *
-                           w->strip_chart.valuedata[i]) / w->strip_chart.scale);
+	    int y = (int) (( w->core.height - 2 * s) -
+			   (int)(( w->core.height - 2 * s) * w->strip_chart.valuedata[i]) / 
+			   w->strip_chart.scale);
 
 	    XFillRectangle(dpy, win, w->strip_chart.fgGC, 
 			   i + s, y + s, (unsigned int) 1,
@@ -390,7 +389,7 @@ Dimension left, width;
 		left + s, j + s, scalewidth + s, j + s);
 	}
     }
-    return( next);
+    return(next);
 }
 
 /*	Function Name: MoveChart
@@ -408,10 +407,11 @@ Boolean blit;
     Dimension s = w->threeD.shadow_width;
     double old_max;
     int left, i, j;
-    register int next = w->strip_chart.interval;
+    int next = w->strip_chart.interval;
 
     if (!XtIsRealized((Widget) w)) return;
 
+    if (w->strip_chart.jump_val < 0) w->strip_chart.jump_val = DEFAULT_JUMP;
     if (w->strip_chart.jump_val == DEFAULT_JUMP)
         j = ( w->core.width - 2 * s) / 2; /* Half the window width. */
     else {
@@ -419,8 +419,9 @@ Boolean blit;
 	if (j < 0) j = 0;
     }
 
-    (void) bcopy((char *)(w->strip_chart.valuedata + next - j ),
-	  (char *)(w->strip_chart.valuedata), j * sizeof(double));
+    (void) memmove((char *)(w->strip_chart.valuedata), 
+		   (char *)(w->strip_chart.valuedata + next - j),
+		   j * sizeof(double));
     next = w->strip_chart.interval = j;
 	
     /*
@@ -444,13 +445,16 @@ Boolean blit;
     }
 
     XCopyArea(XtDisplay((Widget)w), XtWindow((Widget)w), XtWindow((Widget)w),
-	      w->strip_chart.hiGC, (int) (w->strip_chart.jump_val + s), s,
+	      w->strip_chart.hiGC, 
+	      (int) ((w->strip_chart.jump_val == DEFAULT_JUMP) ?
+		     (j + s) : (w->strip_chart.jump_val + s)), s,
 	      (unsigned int) j, (unsigned int) ( w->core.height - 2 * s),
 	      s, s);
 
     XClearArea(XtDisplay((Widget)w), XtWindow((Widget)w), 
 	       (int) j + s, s, 
-	       (unsigned int) w->strip_chart.jump_val,
+	       (unsigned int) ((w->strip_chart.jump_val == DEFAULT_JUMP) ?
+			       j : w->strip_chart.jump_val),
                (unsigned int) ( w->core.height - 2 * s),
 	       FALSE);
 
@@ -505,20 +509,20 @@ static Boolean SetValues (current, request, new, args, num_args)
     return( ret_val );
 }
 
-/*	Function Name: Resize
+/*	Function Name: SetPoints
  *	Description: Sets up the polypoint that will be used to draw in
  *                   the graph lines.
  *	Arguments: w - the StripChart widget.
  *	Returns: none.
  */
 
-#define HEIGHT ( (unsigned int) w->core.height )
+#define HEIGHT ( (unsigned int) w->core.height)
 
 static void
-Resize(gw)
-Widget gw;
+SetPoints(widget)
+Widget widget;
 {
-    StripChartWidget w = (StripChartWidget) gw;
+    StripChartWidget w = (StripChartWidget) widget;
     Dimension s = w->threeD.shadow_width;
     XPoint * points;
     Cardinal size;
@@ -541,9 +545,5 @@ Widget gw;
 	points[i - 1].x = 0;
 	points[i - 1].y = ( short)(((double)w->core.height - 2.0 * (double) s) / (double) w->strip_chart.scale );
     }
-    /* this kind of incremental approach creates a problem with the way the */
-    /* scale bars appear on the graph for larger values .ie. the spread of */
-    /* lines are uniform, but appears incorrect */
     points[0].y += (short)s;
 }
-
